Hello World Example
===============================================================================

:download:`hello_world_view.enaml <../../../examples/tutorial/hello_world/hello_world_view.enaml>`

.. literalinclude:: ../../../examples/tutorial/hello_world/hello_world_view.enaml
    :language: python

::

    $ enaml-run hello_world_view.enaml

.. image:: images/hello_world.png

:download:`hello_world.py<../../../examples/tutorial/hello_world/hello_world.py>`

.. literalinclude:: ../../../examples/tutorial/hello_world/hello_world.py
    :language: python

::

    $ python hello_world.py

.. image:: images/hello_world_python.png
